@@ -15,6 +15,16 @@ __all__ = ["record_audio",
            "play_audio"]
 
 
+def configure_input():
+    from microphone.configure_input import load_ini, get_input_devices, present_menu, save_ini
+    savedDevice = load_ini()
+    inputDevices = get_input_devices()
+    selectedDevice = present_menu(inputDevices, savedDevice)
+    print("'{}' selected as input device".format(selectedDevice['name']))
+    save_ini(selectedDevice)
+
+
+
 def record_audio(time: float, device: Optional[Dict[str, str]] = None) -> Tuple[List[bytes], int]:
     """ Record input stream to in-memory list.
 
